from django.db import models
from django.utils.translation import ugettext_lazy as _
from commons.models import MonthBasedMixin
from django.utils import timezone
from django.utils.timezone import timezone, timedelta, datetime, now
from commons.models import Person
from customers.models import Customer
from viewflow.models import Process
# Create your models here.

# class MyModel(models.Model):
#     name = models.CharField(max_length=250)

class Employee(models.Model):
    class Meta:
        db_table = 'employees'
        verbose_name = _("alkalmazott")
        verbose_name_plural = _("alkalmazottak")

    person = models.ForeignKey(
        verbose_name=_('személyes adatok'),
        to=Person,
        on_delete=models.CASCADE
    )

    def __str__(self) -> str:
        return str(self.person)

class PayrollManager(models.Manager):

    def create(self, employee, year=None, month=None):
        super().create(
            employee=employee,
            year=year if year is not None else now().year,
            month=None if month is not None else now().month,
        )

class Payroll(MonthBasedMixin, Process):

    class Meta:
        db_table = 'payrolls'
        verbose_name = _("bérszámfejtés")
        verbose_name_plural = _("bérszámfejtések")

    objects = PayrollManager()

    employee = models.ForeignKey(
        verbose_name=_('alkalmazott'),
        to=Employee,
        on_delete=models.CASCADE
    )

    employer = models.ForeignKey(
        verbose_name=_('foglalkoztató'),
        to=Customer,
        on_delete=models.CASCADE
    )

    submitted = models.NullBooleanField(
        verbose_name=_('elküldve'),
        help_text=_('hatóság felé elküldve')
    )